@@ -17,7 +17,10 @@ logger = logging.getLogger('djangoldp')
 
 class Customer(Model):
     name = models.CharField(max_length=255, null=True, blank=True)
-    address = models.CharField(max_length=255, null=True, blank=True)
+    address = models.TextField(null=True, blank=True)
+    postcode = models.CharField(max_length=10, null=True, blank=True)
+    city = models.CharField(max_length=50, null=True, blank=True)
+    country = models.CharField(max_length=50, null=True, blank=True)
     logo = models.URLField(blank=True, null=True)
     companyRegister = models.CharField(max_length=255, null=True, blank=True)
     first_name = models.CharField(max_length=255, null=True, blank=True)
@@ -100,6 +103,10 @@ class BusinessProvider(Model):
     name = models.CharField(max_length=255, null=True, blank=True)
     fee = models.PositiveIntegerField(default='0', null=True, blank=True)
 
+    class Meta(Model.Meta):
+        anonymous_perms = ['view']
+        authenticated_perms = ['inherit', 'add', 'delete']
+
     def __str__(self):
         try:
             return '{} ({})'.format(self.name, self.urlid)
